@@ -12,32 +12,24 @@ Demonstrates how all the production engineering components work together:
 """
 
 import asyncio
-import os
 import sys
 from pathlib import Path
 
 # Add parent directory to path
 sys.path.insert(0, str(Path(__file__).parent.parent))
 
-from zerobuffer_serve.config import ConfigManager, TestConfig
-from zerobuffer_serve.logging.structured_logger import (
-    LoggerFactory, 
-    with_correlation, 
-    with_test_context
-)
+from zerobuffer_serve.config import ConfigManager
+from zerobuffer_serve.logging.structured_logger import LoggerFactory, with_correlation, with_test_context
 from zerobuffer_serve.monitoring.resource_monitor import ResourceMonitor
 from zerobuffer_serve.async_manager import AsyncStepManager, AsyncResourceManager
-from zerobuffer_serve.step_definitions.basic_communication_refactored import (
-    BasicCommunicationSteps,
-    PerformanceMonitor
-)
+from zerobuffer_serve.step_definitions.basic_communication_refactored import BasicCommunicationSteps, PerformanceMonitor
 from zerobuffer_serve.test_context import HarmonyTestContext
 
 
 async def run_production_test() -> None:
     """
     Run a test using all production components.
-    
+
     This demonstrates:
     1. Configuration management
     2. Structured logging
@@ -46,12 +38,12 @@ async def run_production_test() -> None:
     5. Performance tracking
     6. Dependency injection
     """
-    
+
     # 1. Configure the test environment
     print("=" * 60)
     print("PRODUCTION INTEGRATION TEST")
     print("=" * 60)
-    
+
     # Override configuration for this test
     config = ConfigManager.override_test_config(
         buffer_timeout_ms=3000,
@@ -59,117 +51,106 @@ async def run_production_test() -> None:
         log_format="json",
         performance_tracking=True,
         resource_monitoring=True,
-        debug_mode=True
+        debug_mode=True,
     )
-    
-    print(f"\n1. Configuration loaded:")
+
+    print("\n1. Configuration loaded:")
     print(f"   - Timeout: {config.buffer_timeout_ms}ms")
     print(f"   - Log Level: {config.log_level}")
     print(f"   - Performance Tracking: {config.performance_tracking}")
-    
+
     # 2. Set up structured logging
-    LoggerFactory.configure(
-        level=config.log_level,
-        output="stdout",
-        format_json=False  # Use text for demo readability
-    )
-    
+    LoggerFactory.configure(level=config.log_level, output="stdout", format_json=False)  # Use text for demo readability
+
     logger = LoggerFactory.get_logger("ProductionTest")
-    
+
     print("\n2. Structured logging configured")
-    
+
     # 3. Create resource monitor
     resource_monitor = ResourceMonitor(
-        logger=logger.logger,
-        warn_memory_mb=config.memory_warning_mb,
-        warn_cpu_percent=config.cpu_warning_percent
+        logger=logger.logger, warn_memory_mb=config.memory_warning_mb, warn_cpu_percent=config.cpu_warning_percent
     )
-    
+
     initial_snapshot = resource_monitor.capture()
-    print(f"\n3. Resource monitoring started:")
+    print("\n3. Resource monitoring started:")
     print(f"   - Initial memory: {initial_snapshot.memory_mb:.1f}MB")
     print(f"   - Initial CPU: {initial_snapshot.cpu_percent:.1f}%")
-    
+
     # 4. Create async managers
     async_manager = AsyncStepManager(logger.logger, config)
     resource_manager = AsyncResourceManager(logger.logger)
-    
+
     print("\n4. Async managers initialized")
-    
+
     # 5. Create performance monitor
     perf_monitor = PerformanceMonitor(logger.logger)
-    
+
     print("\n5. Performance monitoring enabled")
-    
+
     # Run test with correlation context
     with with_correlation() as correlation_id:
         with with_test_context("test_production_integration") as test_id:
-            
-            print(f"\n6. Test context established:")
+
+            print("\n6. Test context established:")
             print(f"   - Correlation ID: {correlation_id}")
             print(f"   - Test ID: {test_id}")
-            
+
             # 7. Create test context and steps with dependency injection
             test_context = HarmonyTestContext()
             test_context.initialize(
-                role="test",
-                platform="python",
-                scenario="Production Integration Test",
-                test_run_id=test_id
+                role="test", platform="python", scenario="Production Integration Test", test_run_id=test_id
             )
-            
+
             # Inject dependencies
             steps = BasicCommunicationSteps(
                 test_context=test_context,
                 logger=logger.logger,
                 buffer_factory=None,  # Use default
-                performance_monitor=perf_monitor
+                performance_monitor=perf_monitor,
             )
-            
+
             print("\n7. Test steps initialized with dependency injection")
-            
+
             # 8. Run test scenario with monitoring
             print("\n8. Running test scenario...")
-            
+
             try:
                 # Track the entire test operation
                 with resource_monitor.track_operation("test_scenario"):
                     with logger.operation("test_execution", scenario="1.1"):
-                        
+
                         # Initialize environment
                         await async_manager.run_step_with_timeout(
-                            run_test_steps(steps),
-                            timeout=10.0,
-                            step_name="test_1_1_simulation"
+                            run_test_steps(steps), timeout=10.0, step_name="test_1_1_simulation"
                         )
-                        
+
                 print("\n   ✅ Test scenario completed successfully")
-                
+
             except Exception as e:
                 print(f"\n   ❌ Test scenario failed: {e}")
-                logger.error(f"Test failed", exc_info=True)
-                
+                logger.error("Test failed", exc_info=True)
+
             finally:
                 # 9. Clean up resources
                 print("\n9. Cleaning up resources...")
                 await resource_manager.cleanup_all()
                 await async_manager.cleanup()
                 test_context.cleanup()
-                
+
             # 10. Report resource usage
             final_snapshot = resource_monitor.capture()
             delta = resource_monitor.calculate_delta(initial_snapshot, final_snapshot)
-            
+
             print("\n10. Resource usage summary:")
             print(f"    - Memory delta: {delta.memory_delta_mb:.1f}MB")
             print(f"    - Files delta: {delta.files_delta}")
             print(f"    - Threads delta: {delta.threads_delta}")
-            
+
             if delta.has_leak():
                 print("    ⚠️  Possible resource leak detected!")
             else:
                 print("    ✅ No resource leaks detected")
-                
+
             # 11. Report performance metrics
             print("\n11. Performance metrics:")
             for operation in ["buffer_creation", "frame_write", "frame_read_verify"]:
@@ -179,16 +160,16 @@ async def run_production_test() -> None:
                     print(f"        Mean: {stats['mean']*1000:.2f}ms")
                     print(f"        Min: {stats['min']*1000:.2f}ms")
                     print(f"        Max: {stats['max']*1000:.2f}ms")
-                    
+
             # 12. Configuration validation
             print("\n12. Configuration validation:")
-            print(f"    - All constraints met: ✅")
-            print(f"    - Type safety enforced: ✅")
-            print(f"    - Environment variables supported: ✅")
-            
+            print("    - All constraints met: ✅")
+            print("    - Type safety enforced: ✅")
+            print("    - Environment variables supported: ✅")
+
             # Export configuration for CI/CD
             env_vars = config.to_env_dict()
-            print(f"\n13. Exportable configuration (first 3):")
+            print("\n13. Exportable configuration (first 3):")
             for key, value in list(env_vars.items())[:3]:
                 print(f"    export {key}={value}")
 
@@ -196,109 +177,89 @@ async def run_production_test() -> None:
 async def run_test_steps(steps: BasicCommunicationSteps) -> None:
     """
     Simulate running test 1.1 steps.
-    
+
     This demonstrates the production-ready step implementations.
     """
     # Initialize test environment
     steps.test_environment_initialized()
     steps.all_processes_ready()
-    
+
     # Create buffer
     await steps.create_buffer(
-        process="reader",
-        buffer_name="test-production",
-        metadata_size="1024",
-        payload_size="10240"
+        process="reader", buffer_name="test-production", metadata_size="1024", payload_size="10240"
     )
-    
+
     # Connect writer
-    await steps.connect_to_buffer(
-        process="writer",
-        buffer_name="test-production"
-    )
-    
+    await steps.connect_to_buffer(process="writer", buffer_name="test-production")
+
     # Write metadata
-    await steps.write_metadata(
-        process="writer",
-        size="100"
-    )
-    
+    await steps.write_metadata(process="writer", size="100")
+
     # Write frame
-    await steps.write_frame_with_sequence(
-        process="writer",
-        size="1024",
-        sequence="1"
-    )
-    
+    await steps.write_frame_with_sequence(process="writer", size="1024", sequence="1")
+
     # Read and verify
-    await steps.read_frame_verify_sequence_size(
-        process="reader",
-        sequence="1",
-        size="1024"
-    )
-    
+    await steps.read_frame_verify_sequence_size(process="reader", sequence="1", size="1024")
+
     # Validate data
-    await steps.validate_frame_data(
-        process="reader"
-    )
-    
+    await steps.validate_frame_data(process="reader")
+
     # Signal completion
-    await steps.signal_space_available(
-        process="reader"
-    )
+    await steps.signal_space_available(process="reader")
 
 
 def demonstrate_type_safety() -> None:
     """
     Demonstrate compile-time type safety with mypy.
-    
+
     This function has intentional type errors that mypy would catch.
     """
     print("\n" + "=" * 60)
     print("TYPE SAFETY DEMONSTRATION")
     print("=" * 60)
-    
+
     print("\nThe following would be caught by mypy type checking:")
-    
+
     # Example 1: Wrong type for configuration
     print("\n1. Configuration type error:")
     print("   config = TestConfig(buffer_timeout_ms='not_a_number')")
     print("   ❌ mypy error: Argument 'buffer_timeout_ms' expected int, got str")
-    
+
     # Example 2: Missing return type
     print("\n2. Missing return type annotation:")
     print("   def process_frame(data: bytes):")
     print("       return len(data)")
     print("   ❌ mypy error: Function missing return type annotation")
-    
+
     # Example 3: Optional handling
     print("\n3. Optional type not handled:")
     print("   frame: Optional[Frame] = get_frame()")
     print("   size = len(frame.data)  # frame might be None!")
     print("   ❌ mypy error: Item 'None' has no attribute 'data'")
-    
+
     # Example 4: Protocol violation
     print("\n4. Protocol implementation missing method:")
     print("   class MyReader(BufferReader):")
     print("       # Missing: def get_metadata(self) -> bytes")
     print("   ❌ mypy error: Cannot instantiate abstract class 'MyReader'")
-    
+
     print("\nRunning './test.sh --type-check-only' catches these before runtime!")
 
 
 def main() -> None:
     """Main entry point."""
-    
+
     # Run the integration test
     asyncio.run(run_production_test())
-    
+
     # Demonstrate type safety
     demonstrate_type_safety()
-    
+
     print("\n" + "=" * 60)
     print("PRODUCTION INTEGRATION TEST COMPLETE")
     print("=" * 60)
-    print("""
+    print(
+        """
 Key Production Benefits Demonstrated:
 1. ✅ Type-safe configuration with validation
 2. ✅ Structured logging with trace context
@@ -313,8 +274,9 @@ Key Production Benefits Demonstrated:
 
 All components work together to provide a robust,
 maintainable, and production-ready test framework!
-    """)
+    """
+    )
 
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
