@@ -21,7 +21,6 @@ sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 from pytest_bdd import scenario, given, when, then, parsers
 
 # Import ZeroBuffer components
-from zerobuffer import Reader, Writer, BufferConfig
 from zerobuffer_serve.test_context import HarmonyTestContext
 from zerobuffer_serve.logging.dual_logger import DualLoggerProvider
 from zerobuffer_serve.step_definitions.basic_communication import BasicCommunicationSteps
@@ -31,13 +30,21 @@ from zerobuffer_serve.step_definitions.basic_communication import BasicCommunica
 FEATURE_FILE = Path(__file__).parent.parent / "features" / "01-BasicCommunication.feature"
 if not FEATURE_FILE.exists():
     # Fallback to original locations
-    FEATURE_FILE = Path(__file__).parent.parent.parent / "ZeroBuffer.Harmony.Tests" / "Features" / "01-BasicCommunication.feature"
+    FEATURE_FILE = (
+        Path(__file__).parent.parent.parent / "ZeroBuffer.Harmony.Tests" / "Features" / "01-BasicCommunication.feature"
+    )
     if not FEATURE_FILE.exists():
-        FEATURE_FILE = Path(__file__).parent.parent.parent / "csharp" / "ZeroBuffer.Tests" / "Features" / "01-BasicCommunication.feature"
+        FEATURE_FILE = (
+            Path(__file__).parent.parent.parent
+            / "csharp"
+            / "ZeroBuffer.Tests"
+            / "Features"
+            / "01-BasicCommunication.feature"
+        )
 
 
 # Define the scenario
-@scenario(str(FEATURE_FILE), 'Test 1.1 - Simple Write-Read Cycle')
+@scenario(str(FEATURE_FILE), "Test 1.1 - Simple Write-Read Cycle")
 def test_simple_write_read_cycle() -> None:
     """Test 1.1 - Simple Write-Read Cycle"""
     pass
@@ -49,10 +56,7 @@ def test_context() -> Generator[HarmonyTestContext, None, None]:
     """Provide test context"""
     context = HarmonyTestContext()
     context.initialize(
-        role="test",
-        platform="python", 
-        scenario="Test 1.1 - Simple Write-Read Cycle",
-        test_run_id="pytest-bdd-1.1"
+        role="test", platform="python", scenario="Test 1.1 - Simple Write-Read Cycle", test_run_id="pytest-bdd-1.1"
     )
     yield context
     context.cleanup()
@@ -84,6 +88,7 @@ def run_async(coro: Coroutine[Any, Any, Any]) -> Any:
 
 # Step definitions - wrapping the class methods for pytest-bdd
 
+
 # Background steps
 @given("the test environment is initialized")
 def test_environment_initialized(steps: BasicCommunicationSteps) -> None:
@@ -98,8 +103,14 @@ def all_processes_ready(steps: BasicCommunicationSteps) -> None:
 
 
 # Scenario steps
-@given(parsers.re(r"the '(?P<process>[^']+)' process creates buffer '(?P<buffer_name>[^']+)' with metadata size '(?P<metadata_size>\d+)' and payload size '(?P<payload_size>\d+)'"))
-def create_buffer(steps: BasicCommunicationSteps, process: str, buffer_name: str, metadata_size: str, payload_size: str) -> Any:
+@given(
+    parsers.re(
+        r"the '(?P<process>[^']+)' process creates buffer '(?P<buffer_name>[^']+)' with metadata size '(?P<metadata_size>\d+)' and payload size '(?P<payload_size>\d+)'"
+    )
+)
+def create_buffer(
+    steps: BasicCommunicationSteps, process: str, buffer_name: str, metadata_size: str, payload_size: str
+) -> Any:
     """Create a new ZeroBuffer with specified configuration"""
     return run_async(steps.create_buffer(process, buffer_name, metadata_size, payload_size))
 
@@ -116,13 +127,21 @@ def write_metadata(steps: BasicCommunicationSteps, process: str, size: str) -> A
     return run_async(steps.write_metadata(process, size))
 
 
-@when(parsers.re(r"the '(?P<process>[^']+)' process writes frame with size '(?P<size>\d+)' and sequence '(?P<sequence>\d+)'"))
+@when(
+    parsers.re(
+        r"the '(?P<process>[^']+)' process writes frame with size '(?P<size>\d+)' and sequence '(?P<sequence>\d+)'"
+    )
+)
 def write_frame_with_sequence(steps: BasicCommunicationSteps, process: str, size: str, sequence: str) -> Any:
     """Write a frame with specific size and sequence"""
     return run_async(steps.write_frame_with_sequence(process, size, sequence))
 
 
-@then(parsers.re(r"the '(?P<process>[^']+)' process should read frame with sequence '(?P<sequence>\d+)' and size '(?P<size>\d+)'"))
+@then(
+    parsers.re(
+        r"the '(?P<process>[^']+)' process should read frame with sequence '(?P<sequence>\d+)' and size '(?P<size>\d+)'"
+    )
+)
 def read_frame_verify_sequence_size(steps: BasicCommunicationSteps, process: str, sequence: str, size: str) -> Any:
     """Read and verify frame with sequence and size"""
     return run_async(steps.read_frame_verify_sequence_size(process, sequence, size))
@@ -144,6 +163,6 @@ if __name__ == "__main__":
     # Run this specific test
     print(f"Feature file: {FEATURE_FILE}")
     print(f"Feature file exists: {FEATURE_FILE.exists()}")
-    
+
     # Run the test
-    pytest.main([__file__, "-v", "-s"])
\ No newline at end of file
+    pytest.main([__file__, "-v", "-s"])
